#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.container.contained import Contained
from zope.interface import Interface, implementer
from zope.location import ILocation
from zope.schema.fieldproperty import FieldProperty

from pyams_content.features.search.portlet import ISearchResultsPortletSettings
from pyams_default_theme.features.search.portlet.interfaces import ISearchResultsPortletDefaultRendererSettings
from pyams_default_theme.interfaces import ISearchResultsView
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_skin.interfaces.viewlet import IBreadcrumbs
from pyams_skin.layer import IPyAMSLayer, IPyAMSUserLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config, NullAdapter
from pyams_utils.factory import factory_config

from pyams_default_theme import _


@factory_config(provided=ISearchResultsPortletDefaultRendererSettings)
class SearchResultsPortletDefaultRendererSettings(Persistent, Contained):
    """Search results portlet default renderer settings"""

    display_results_count = FieldProperty(ISearchResultsPortletDefaultRendererSettings['display_results_count'])
    allow_sorting = FieldProperty(ISearchResultsPortletDefaultRendererSettings['allow_sorting'])
    allow_pagination = FieldProperty(ISearchResultsPortletDefaultRendererSettings['allow_pagination'])


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, ISearchResultsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/search-results.pt', layer=IPyAMSLayer)
@implementer(ISearchResultsView)
class SearchResultsPortletDefaultRenderer(PortletRenderer):
    """Search results portlet default renderer"""

    label = _("Default search results")

    settings_interface = ISearchResultsPortletDefaultRendererSettings

    def update(self):
        settings = self.renderer_settings
        if not settings.allow_pagination:
            self.request.GET['length'] = '999'
        super(SearchResultsPortletDefaultRenderer, self).update()


@adapter_config(context=(ILocation, IPyAMSUserLayer, ISearchResultsView), provides=IBreadcrumbs)
class BreadcrumbsAdapter(NullAdapter):
    """Disable breadcrumbs in search results view"""
